@@ -34,7 +34,7 @@ void set_nut_table(void);
 void label_nut_list(int);
 void get_nut_value(float *);
 void guess_recipe();
-void solve_it(int, int *, int *);
+void solve_it(int, int *, int *, int *);
 void modify_servings(void);
 
 #endif
