@@ -180,6 +180,9 @@ while (max > 0)
       DVMap[count+1] == CHOLE || DVMap[count+1] == OMEGA6 ||
       DVMap[count+1] == CHO_NONFIB || DVMap[count+1] == OMEGA3 ||
       DVMap[count+1] == CHOCDF ||
+      (DVMap[count+1] == AA  && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
+      (DVMap[count+1] == EPA && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
+      (DVMap[count+1] == DHA && DV[AA] - 0.01 < .00001 && DV[EPA] - 0.01 < .00001 && DV[DHA] - 0.01 < .00001 ) ||
       food_work.nutrient[DVMap[count+1]] / DV[DVMap[count+1]] >= .9999) deficpct[count] = 0;
    else 
     {
